@@ -1,7 +1,7 @@
 # ============================================================
 #
 # Copyright (C) 2010 by Johannes Wienke <jwienke at techfak dot uni-bielefeld dot de>
-# Copyright (C) 2011-2017 Jan Moringen <jmoringe@techfak.uni-bielefeld.de>
+# Copyright (C) 2011-2018 Jan Moringen <jmoringe@techfak.uni-bielefeld.de>
 #
 # This file may be licensed under the terms of the
 # GNU Lesser General Public License Version 3 (the ``LGPL''),
@@ -46,6 +46,10 @@ import os
 import platform
 import ConfigParser
 
+from rsb.util import getLoggerByClass, Enum
+import rsb.eventprocessing
+
+
 _logger = logging.getLogger('rsb')
 
 
@@ -61,9 +65,6 @@ class _NullHandler(logging.Handler):
         pass
 _logger.addHandler(_NullHandler())
 
-from rsb.util import getLoggerByClass, Enum
-import rsb.eventprocessing
-import rsb.filter
 
 _spreadAvailable = False
 try:
@@ -82,6 +83,7 @@ def haveSpread():
     """
     return _spreadAvailable
 
+
 __defaultTransportsRegistered = False
 __transportRegistrationLock = threading.RLock()
 
@@ -2061,6 +2063,26 @@ def _initializeIntrospection():
 
 
 def createParticipant(cls, scope, config, parent=None, **kwargs):
+    """
+    Creates and returns a new participant of type `cls`.
+
+    Args:
+        cls (type):
+            The type of participant that should be created. For
+            example :obj:`Listener`.
+        scope (Scope or accepted by :obj:`Scope` constructor):
+            the scope of the new participant. Can be a :obj:`Scope` object
+            or a string.
+        config (ParticipantConfig):
+            The configuration that should be used by the new participant.
+        parent (Participant or NoneType):
+            ``None`` or the :obj:`Participant` which should be considered the
+            parent of the new participant.
+
+    Returns:
+        Participant:
+            A new :obj:`Participant` object of type `cls`.
+    """
     if config is None:
         config = getDefaultParticipantConfig()
     __registerDefaultTransports()
